Build$Partition$$Methods extension

on

Properties

buildTimeMillis int

Available on Build$Partition, provided by the Build$Partition$$Methods extension

from: public long getBuildTimeMillis()
no setter
fingerprint → JString?

Available on Build$Partition, provided by the Build$Partition$$Methods extension

from: public java.lang.String getFingerprint() The returned object must be released after use, by calling the release method.
no setter
name → JString?

Available on Build$Partition, provided by the Build$Partition$$Methods extension

from: public java.lang.String getName() The returned object must be released after use, by calling the release method.
no setter

Methods

equals(JObject? object) bool

Available on Build$Partition, provided by the Build$Partition$$Methods extension

from: public boolean equals(java.lang.Object object)
hashCode$1() int

Available on Build$Partition, provided by the Build$Partition$$Methods extension

from: public int hashCode()