Partition class
Build information for a particular device partition.
Properties
- buildTimeMillis → int
-
The time (ms since epoch), at which this partition was built, see Build.time.
final
- fingerprint → String?
-
The build fingerprint of this partition, see Build.fingerprint.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
The name of this partition, e.g. "system", or "vendor"
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- partitionNameSystem → const String
- The name identifying the system partition.